@@ -1,6 +1,9 @@
-from flask import current_app as app
+from datetime import datetime, timedelta
+from distutils.util import strtobool
+
+import pytz
 from flask import abort, jsonify, request
-from jsonschema.exceptions import ValidationError, SchemaError
+from flask import current_app as app
 
 from director.api import api_bp, validate
 from director.auth import auth
@@ -8,6 +11,7 @@ from director.builder import WorkflowBuilder
 from director.exceptions import WorkflowNotFound
 from director.extensions import cel_workflows, schema
 from director.models.workflows import Workflow
+from director.utils import build_celery_schedule
 
 
 def _get_workflow(workflow_id):
@@ -41,6 +45,14 @@ def _execute_workflow(project, name, payload={}):
     return obj.to_dict(), workflow
 
 
+def _cancel_workflow(obj):
+    workflow = WorkflowBuilder(obj.id)
+    workflow.cancel()
+
+    app.logger.info(f"Workflow {obj.id} canceled")
+    return obj.to_dict(), workflow
+
+
 @api_bp.route("/workflows", methods=["POST"])
 @auth.login_required
 @schema.validate(
@@ -72,17 +84,35 @@ def relaunch_workflow(workflow_id):
     return jsonify(data), 201
 
 
+@api_bp.route("/workflows/<workflow_id>/cancel", methods=["POST"])
+@auth.login_required
+def cancel_workflow(workflow_id):
+    obj = _get_workflow(workflow_id)
+    data, _ = _cancel_workflow(obj)
+    return jsonify(data), 201
+
+
 @api_bp.route("/workflows")
 @auth.login_required
 def list_workflows():
     page = request.args.get("page", type=int, default=1)
+    # Convert with_payload arg to boolean, if we encounter an error,
+    # ignore and set with_payload to its default value (True)
+    # We don't do request.args.get with type=bool because it doesn't seem to work as expected because
+    # this most likely casts the string as bool which is not the proper string to bool conversion we need
+    try:
+        with_payload = strtobool(
+            request.args.get("with_payload", type=str, default="True")
+        )
+    except ValueError:
+        with_payload = True
     per_page = request.args.get(
         "per_page", type=int, default=app.config["WORKFLOWS_PER_PAGE"]
     )
     workflows = Workflow.query.order_by(Workflow.created_at.desc()).paginate(
         page, per_page
     )
-    return jsonify([w.to_dict() for w in workflows.items])
+    return jsonify([w.to_dict(with_payload=with_payload) for w in workflows.items])
 
 
 @api_bp.route("/workflows/<workflow_id>")
@@ -94,3 +124,15 @@ def get_workflow(workflow_id):
     resp = workflow.to_dict()
     resp.update({"tasks": tasks})
     return jsonify(resp)
+
+
+@api_bp.route("/definitions")
+@auth.login_required
+def list_definitions():
+    workflow_definitions = []
+    for fullname, definition in sorted(cel_workflows.workflows.items()):
+        project, name = fullname.split(".", 1)
+        workflow_definitions.append(
+            {"fullname": fullname, "project": project, "name": name, **definition}
+        )
+    return jsonify(workflow_definitions)
